@@ -1,7 +1,7 @@
 """
 Configuration API endpoints for VibeSurf Backend
 
-Handles LLM Profile and controller configuration management.
+Handles LLM Profile and tools configuration management.
 """
 
 from fastapi import APIRouter, HTTPException, Depends
@@ -18,7 +18,10 @@ from .models import (
 )
 
 router = APIRouter(prefix="/config", tags=["config"])
-logger = logging.getLogger(__name__)
+
+from vibe_surf.logger import get_logger
+
+logger = get_logger(__name__)
 
 def _profile_to_response_dict(profile) -> dict:
     """Convert SQLAlchemy LLMProfile to dict for Pydantic validation - safe extraction"""
@@ -115,10 +118,24 @@ async def create_llm_profile(
         
     except Exception as e:
         logger.error(f"Failed to create LLM profile: {e}")
-        raise HTTPException(
-            status_code=500,
-            detail=f"Failed to create LLM profile: {str(e)}"
-        )
+        
+        # Handle specific database constraint errors
+        error_msg = str(e)
+        if "UNIQUE constraint failed: llm_profiles.profile_name" in error_msg:
+            raise HTTPException(
+                status_code=400,
+                detail=f"Profile with name '{profile_request.profile_name}' already exists. Please choose a different name."
+            )
+        elif "IntegrityError" in error_msg and "profile_name" in error_msg:
+            raise HTTPException(
+                status_code=400,
+                detail=f"Profile name '{profile_request.profile_name}' is already in use. Please choose a different name."
+            )
+        else:
+            raise HTTPException(
+                status_code=500,
+                detail=f"Failed to create LLM profile: {str(e)}"
+            )
 
 @router.get("/llm-profiles", response_model=List[LLMProfileResponse])
 async def list_llm_profiles(
@@ -217,7 +234,9 @@ async def update_llm_profile(
         
         # Return updated profile
         updated_profile = await LLMProfileQueries.get_profile(db, profile_name)
-        
+        from ..shared_state import current_llm_profile_name
+        if current_llm_profile_name != profile_name:
+            current_llm_profile_name = None
         # Use safe extraction to avoid greenlet issues
         return LLMProfileResponse(**_profile_to_response_dict(updated_profile))
         
@@ -640,8 +659,8 @@ async def get_configuration_status(db: AsyncSession = Depends(get_db_session)):
                 "default_profile": default_profile.profile_name if default_profile else None,
                 "has_default": default_profile is not None
             },
-            "controller": {
-                "initialized": shared_state.controller is not None
+            "tools": {
+                "initialized": shared_state.vibesurf_tools is not None
             },
             "browser_manager": {
                 "initialized": shared_state.browser_manager is not None
@@ -652,7 +671,7 @@ async def get_configuration_status(db: AsyncSession = Depends(get_db_session)):
             },
             "overall_status": "ready" if (
                     default_profile and
-                    shared_state.controller and
+                    shared_state.vibesurf_tools and
                     shared_state.browser_manager and
                     shared_state.vibesurf_agent
             ) else "partial"
