@@ -56,7 +56,7 @@ class BrowserUseAgentExecution(BaseModel):
     """Parameters for executing browser_use agent tasks in parallel"""
     tasks: list[BrowserUseAgentTask] = Field(
         description='List of tasks to execute concurrently using browser_use agents for improved efficiency. '
-                    'If only one task is provided, the agent can take over the entire browser and can also see and operate all tabs.',
+                    'If only one task and no tab_id is provided, the agent can take over the entire browser and can also see and operate all tabs.',
         min_length=1,
     )
 
